/*
DL2 Monitor: ./pa/libpa.c
Copyright (C) 2002, Rolf Jger, Ulm (Germany)

See the file README for information on usage and redistribution
of this source code file, and for a DISCLAIMER OF ALL WARRANTIES.
*/

/*----------------------------------------------------------------------------
 * Datalink Monitor (libpa): Protocol Analysis Library 
 * 
 * This module is to place general purpose functions needed by the library
 * libdl2pa.so, and to setup commonly used tables. The pa_libinit() function
 * should be used to do such initializations.
 *
 * Implementation Notes:
 * -pa_portname (global)
 *  This array defines the acronyms of well-know port numbers to be used 
 *  elsewhere. PORTLIST_LENGTH denotes the number of supported acronyms.
 * -pa_port2idx (global)
 *  This array maps a port number to an index which can be used to access the
 *  corresponding acronym. The range of port numbers has been restricted to
 *  N_PORTNUMBERS.
 *
 * Author: Rolf Jger,Ulm
 *----------------------------------------------------------------------------
 * YYYYMMDD  History
 * 20020414  created from scratch
 * $Id: libpa.c,v 1.2 2002/04/22 15:45:50 dv Exp $
 *----------------------------------------------------------------------------
*/
# include "lib/dl2pa.h"
# include "pa/portmap.h"

# define N_PORTNUMBERS PA_N_PORTNUMBERS

const char *dl2pa_portname[] = {
		//   P   I
  "?port",	//   ?   0    
  "psmux",	//   1   1 Port Service Multiplexer
  "echo",	//   7   2 Server Echo Return
  "discard",	//   9   3 Server Discard Request
  "daytime",	//  13   4 Server Date+Time Return
  "chargen",	//  19   5 Server Character Generator, tty test
  "ftpd",	//  20   6 FTP Data Line Connection
  "ftpc",	//  21   7 FTP Control Line Connection
  "telnet",	//  23   8 Telnet
  "smtp",	//  25   9 Simple Mail Transport
  "time",	//  37  10 Time Server Request
  "rap",	//  38  11 Route Access Protocol
  "rlp",	//  39  12 Resource Location Protocol 
  "hns",	//  42  13 Host Name Server
  "dom",	//  53  14 Domain Name Server
  "bsps",	//  67  15 Bootstrap Protocol Server
  "bspc",	//  68  16 Bootstrap Protocol Client
  "tftp",	//  69  17 Trivial File Transfer
  "finger",	//  79  18 finger
  "http",	//  80  19 http
  "nics",	// 101  20 NIC Host Name Server
  "rtelnet",	// 107  21 Remote Telnet
  "pop2",	// 109  22 Post Office Protocol (Version 2) Server
  "pop3",	// 110  23 POP3 Server
  "auth",	// 113  24 Authentication Service
  "nntp",	// 119  25 Network News Transfer
  "ntp",	// 123  26 Network Time Protocol
  "snmp",	// 161  27 snmp
  0		// end-of-list
};
# define PORTLIST_LENGTH 28 

static Octet pa_port2idx[N_PORTNUMBERS];
const Octet *dl2pa_port2idx = pa_port2idx;

void dl2pa_libinit(void) { 
  int i;

  // initialize port2index translation: 
  for (i = 0; i < N_PORTNUMBERS; i++) pa_port2idx[i] = 0;
  pa_port2idx[  1] =  1;
  pa_port2idx[  7] =  2;
  pa_port2idx[  9] =  3;
  pa_port2idx[ 13] =  4;
  pa_port2idx[ 19] =  5;
  pa_port2idx[ 20] =  6;
  pa_port2idx[ 21] =  7;
  pa_port2idx[ 23] =  8;
  pa_port2idx[ 25] =  9;
  pa_port2idx[ 37] = 10;
  pa_port2idx[ 38] = 11;
  pa_port2idx[ 39] = 12;
  pa_port2idx[ 42] = 13;
  pa_port2idx[ 53] = 14;
  pa_port2idx[ 67] = 15;
  pa_port2idx[ 68] = 16;
  pa_port2idx[ 69] = 17;
  pa_port2idx[ 79] = 18;
  pa_port2idx[ 80] = 19;
  pa_port2idx[101] = 20;
  pa_port2idx[107] = 21;
  pa_port2idx[109] = 22;
  pa_port2idx[110] = 23;
  pa_port2idx[113] = 24;
  pa_port2idx[119] = 25;
  pa_port2idx[123] = 26;
  pa_port2idx[161] = 27;

  // others follow here:
} //dl2pa_libinit

/***EOM***/
